[![Build Status](https://travis-ci.org/damian-horna/multi-imbalance.svg?branch=master)](https://travis-ci.org/damian-horna/multi-imbalance)

# multi-imbalance

multi-imbalance is a python package tackling the problem of multi-class imbalanced datasets in machine learning.